==> huaweicloudsdkcloudrtc-3.0.79-py2.py3-none-any.whl: huaweicloudsdkcloudrtc/v1/model/abnormal_event_dimension_value.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AbnormalEventDimensionValue:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'abnormal_type': 'int',
        'abnormal_type_desc': 'str',
        'abnormal_factor': 'int',
        'abnormal_factor_desc': 'str',
        'user_count': 'int'
    }

    attribute_map = {
        'abnormal_type': 'abnormal_type',
        'abnormal_type_desc': 'abnormal_type_desc',
        'abnormal_factor': 'abnormal_factor',
        'abnormal_factor_desc': 'abnormal_factor_desc',
        'user_count': 'user_count'
    }

    def __init__(self, abnormal_type=None, abnormal_type_desc=None, abnormal_factor=None, abnormal_factor_desc=None, user_count=None):
        """AbnormalEventDimensionValue - a model defined in huaweicloud sdk"""
        
        

        self._abnormal_type = None
        self._abnormal_type_desc = None
        self._abnormal_factor = None
        self._abnormal_factor_desc = None
        self._user_count = None
        self.discriminator = None

        self.abnormal_type = abnormal_type
        self.abnormal_type_desc = abnormal_type_desc
        self.abnormal_factor = abnormal_factor
        self.abnormal_factor_desc = abnormal_factor_desc
        self.user_count = user_count

    @property
    def abnormal_type(self):
        """Gets the abnormal_type of this AbnormalEventDimensionValue.

        异常类型： - 1：进房慢(5s加入房间失败) - 2：视频卡顿 - 3：音频卡顿 

        :return: The abnormal_type of this AbnormalEventDimensionValue.
        :rtype: int
        """
        return self._abnormal_type

    @abnormal_type.setter
    def abnormal_type(self, abnormal_type):
        """Sets the abnormal_type of this AbnormalEventDimensionValue.

        异常类型： - 1：进房慢(5s加入房间失败) - 2：视频卡顿 - 3：音频卡顿 

        :param abnormal_type: The abnormal_type of this AbnormalEventDimensionValue.
        :type: int
        """
        self._abnormal_type = abnormal_type

    @property
    def abnormal_type_desc(self):
        """Gets the abnormal_type_desc of this AbnormalEventDimensionValue.

        异常类型描述与异常类型对应，支持国际化，取值范围为： - 进房慢(5s加入房间失败) - 视频卡顿 - 音频卡顿 

        :return: The abnormal_type_desc of this AbnormalEventDimensionValue.
        :rtype: str
        """
        return self._abnormal_type_desc

    @abnormal_type_desc.setter
    def abnormal_type_desc(self, abnormal_type_desc):
        """Sets the abnormal_type_desc of this AbnormalEventDimensionValue.

        异常类型描述与异常类型对应，支持国际化，取值范围为： - 进房慢(5s加入房间失败) - 视频卡顿 - 音频卡顿 

        :param abnormal_type_desc: The abnormal_type_desc of this AbnormalEventDimensionValue.
        :type: str
        """
        self._abnormal_type_desc = abnormal_type_desc

    @property
    def abnormal_factor(self):
        """Gets the abnormal_factor of this AbnormalEventDimensionValue.

        异常因素 当异常类型为1时，异常因素取值范围为： - 1：建链失败 - 2：房间非空闲 - 3：服务器异常 - 4：服务器反馈503 - 5：鉴权失败 - 6：鉴权重试 - 7：时钟同步失败 - 8：url错误 - 9：终端内部异常 - 90000004：SDK发出的加入房间信令响应超时 - 90100009：web侧没有收到MSP下发的配置信息 - 90100008：websocket链路建链失败 - 10000001：服务侧返回的异常信息 - 31000003：服务侧返回的异常信息 - 32000030：服务侧返回的异常信息 - 15：浏览器设置sdp异常 当异常类型为2或者3时，异常因素取值范围为： - 1：系统CPU占用高 - 2：App CPU占用高 - 3：音频上行网络延时 - 4：音频上行网络抖动 - 5：视频上行网络延时 - 6：视频上行网络抖动 - 7：音频下行网络延时 - 8：音频下行网络抖动 - 9：视频下行网络延时 - 10：视频下行网络抖动 - 11：上行音频丢包 - 12：上行视频丢包 - 13：下行音频丢包 - 14：下行视频丢包 - 15：下行音频无声音 - 16：其他 - 17：对端用户离线 - 18：对端用户无码流 - 19：对端用户无帧率 - 20：本端服务器下行无码流 - 21：本端服务器下行无帧率 

        :return: The abnormal_factor of this AbnormalEventDimensionValue.
        :rtype: int
        """
        return self._abnormal_factor

    @abnormal_factor.setter
    def abnormal_factor(self, abnormal_factor):
        """Sets the abnormal_factor of this AbnormalEventDimensionValue.

        异常因素 当异常类型为1时，异常因素取值范围为： - 1：建链失败 - 2：房间非空闲 - 3：服务器异常 - 4：服务器反馈503 - 5：鉴权失败 - 6：鉴权重试 - 7：时钟同步失败 - 8：url错误 - 9：终端内部异常 - 90000004：SDK发出的加入房间信令响应超时 - 90100009：web侧没有收到MSP下发的配置信息 - 90100008：websocket链路建链失败 - 10000001：服务侧返回的异常信息 - 31000003：服务侧返回的异常信息 - 32000030：服务侧返回的异常信息 - 15：浏览器设置sdp异常 当异常类型为2或者3时，异常因素取值范围为： - 1：系统CPU占用高 - 2：App CPU占用高 - 3：音频上行网络延时 - 4：音频上行网络抖动 - 5：视频上行网络延时 - 6：视频上行网络抖动 - 7：音频下行网络延时 - 8：音频下行网络抖动 - 9：视频下行网络延时 - 10：视频下行网络抖动 - 11：上行音频丢包 - 12：上行视频丢包 - 13：下行音频丢包 - 14：下行视频丢包 - 15：下行音频无声音 - 16：其他 - 17：对端用户离线 - 18：对端用户无码流 - 19：对端用户无帧率 - 20：本端服务器下行无码流 - 21：本端服务器下行无帧率 

        :param abnormal_factor: The abnormal_factor of this AbnormalEventDimensionValue.
        :type: int
        """
        self._abnormal_factor = abnormal_factor

    @property
    def abnormal_factor_desc(self):
        """Gets the abnormal_factor_desc of this AbnormalEventDimensionValue.

        异常因素描述，支持国际化 当异常类型为1时，异常因素描述与异常因素对应，取值范围为： - 建链失败 - 房间非空闲 - 服务器异常 - 服务器反馈503 - 鉴权失败 - 鉴权重试 - 时钟同步失败 - url错误 - 终端内部异常 - SDK发出的加入房间信令响应超时 - web侧没有收到MSP下发的配置信息 - websocket链路建链失败 - 服务侧返回的异常信息 - 服务侧返回的异常信息 - 服务侧返回的异常信息 - 浏览器设置sdp异常 当异常类型为2或者3时，异常因素描述与异常因素对应，取值范围为： - 系统CPU占用高 - App CPU占用高 - 音频上行网络延时 - 音频上行网络抖动 - 视频上行网络延时 - 视频上行网络抖动 - 音频下行网络延时 - 音频下行网络抖动 - 视频下行网络延时 - 视频下行网络抖动 - 上行音频丢包 - 上行视频丢包 - 下行音频丢包 - 下行视频丢包 - 下行音频无声音 - 其他 - 对端用户离线 - 对端用户无码流 - 对端用户无帧率 - 本端服务器下行无码流 - 本端服务器下行无帧率 其他情况，异常因素描述为：其他 

        :return: The abnormal_factor_desc of this AbnormalEventDimensionValue.
        :rtype: str
        """
        return self._abnormal_factor_desc

    @abnormal_factor_desc.setter
    def abnormal_factor_desc(self, abnormal_factor_desc):
        """Sets the abnormal_factor_desc of this AbnormalEventDimensionValue.

        异常因素描述，支持国际化 当异常类型为1时，异常因素描述与异常因素对应，取值范围为： - 建链失败 - 房间非空闲 - 服务器异常 - 服务器反馈503 - 鉴权失败 - 鉴权重试 - 时钟同步失败 - url错误 - 终端内部异常 - SDK发出的加入房间信令响应超时 - web侧没有收到MSP下发的配置信息 - websocket链路建链失败 - 服务侧返回的异常信息 - 服务侧返回的异常信息 - 服务侧返回的异常信息 - 浏览器设置sdp异常 当异常类型为2或者3时，异常因素描述与异常因素对应，取值范围为： - 系统CPU占用高 - App CPU占用高 - 音频上行网络延时 - 音频上行网络抖动 - 视频上行网络延时 - 视频上行网络抖动 - 音频下行网络延时 - 音频下行网络抖动 - 视频下行网络延时 - 视频下行网络抖动 - 上行音频丢包 - 上行视频丢包 - 下行音频丢包 - 下行视频丢包 - 下行音频无声音 - 其他 - 对端用户离线 - 对端用户无码流 - 对端用户无帧率 - 本端服务器下行无码流 - 本端服务器下行无帧率 其他情况，异常因素描述为：其他 

        :param abnormal_factor_desc: The abnormal_factor_desc of this AbnormalEventDimensionValue.
        :type: str
        """
        self._abnormal_factor_desc = abnormal_factor_desc

    @property
    def user_count(self):
        """Gets the user_count of this AbnormalEventDimensionValue.

        异常影响的用户数

        :return: The user_count of this AbnormalEventDimensionValue.
        :rtype: int
        """
        return self._user_count

    @user_count.setter
    def user_count(self, user_count):
        """Sets the user_count of this AbnormalEventDimensionValue.

        异常影响的用户数

        :param user_count: The user_count of this AbnormalEventDimensionValue.
        :type: int
        """
        self._user_count = user_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AbnormalEventDimensionValue):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcloudrtc-3.0.89-py2.py3-none-any.whl: huaweicloudsdkcloudrtc/v1/model/abnormal_event_dimension_value.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AbnormalEventDimensionValue:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'abnormal_type': 'int',
        'abnormal_type_desc': 'str',
        'abnormal_factor': 'int',
        'abnormal_factor_desc': 'str',
        'user_count': 'int'
    }

    attribute_map = {
        'abnormal_type': 'abnormal_type',
        'abnormal_type_desc': 'abnormal_type_desc',
        'abnormal_factor': 'abnormal_factor',
        'abnormal_factor_desc': 'abnormal_factor_desc',
        'user_count': 'user_count'
    }

    def __init__(self, abnormal_type=None, abnormal_type_desc=None, abnormal_factor=None, abnormal_factor_desc=None, user_count=None):
        """AbnormalEventDimensionValue

        The model defined in huaweicloud sdk

        :param abnormal_type: 异常类型： - 1：进房慢(5s加入房间失败) - 2：视频卡顿 - 3：音频卡顿 
        :type abnormal_type: int
        :param abnormal_type_desc: 异常类型描述与异常类型对应，支持国际化，取值范围为： - 进房慢(5s加入房间失败) - 视频卡顿 - 音频卡顿 
        :type abnormal_type_desc: str
        :param abnormal_factor: 异常因素 当异常类型为1时，异常因素取值范围为： - 1：建链失败 - 2：房间非空闲 - 3：服务器异常 - 4：服务器反馈503 - 5：鉴权失败 - 6：鉴权重试 - 7：时钟同步失败 - 8：url错误 - 9：终端内部异常 - 90000004：SDK发出的加入房间信令响应超时 - 90100009：web侧没有收到MSP下发的配置信息 - 90100008：websocket链路建链失败 - 10000001：服务侧返回的异常信息 - 31000003：服务侧返回的异常信息 - 32000030：服务侧返回的异常信息 - 15：浏览器设置sdp异常 当异常类型为2或者3时，异常因素取值范围为： - 1：系统CPU占用高 - 2：App CPU占用高 - 3：音频上行网络延时 - 4：音频上行网络抖动 - 5：视频上行网络延时 - 6：视频上行网络抖动 - 7：音频下行网络延时 - 8：音频下行网络抖动 - 9：视频下行网络延时 - 10：视频下行网络抖动 - 11：上行音频丢包 - 12：上行视频丢包 - 13：下行音频丢包 - 14：下行视频丢包 - 15：下行音频无声音 - 16：其他 - 17：对端用户离线 - 18：对端用户无码流 - 19：对端用户无帧率 - 20：本端服务器下行无码流 - 21：本端服务器下行无帧率 
        :type abnormal_factor: int
        :param abnormal_factor_desc: 异常因素描述，支持国际化 当异常类型为1时，异常因素描述与异常因素对应，取值范围为： - 建链失败 - 房间非空闲 - 服务器异常 - 服务器反馈503 - 鉴权失败 - 鉴权重试 - 时钟同步失败 - url错误 - 终端内部异常 - SDK发出的加入房间信令响应超时 - web侧没有收到MSP下发的配置信息 - websocket链路建链失败 - 服务侧返回的异常信息 - 服务侧返回的异常信息 - 服务侧返回的异常信息 - 浏览器设置sdp异常 当异常类型为2或者3时，异常因素描述与异常因素对应，取值范围为： - 系统CPU占用高 - App CPU占用高 - 音频上行网络延时 - 音频上行网络抖动 - 视频上行网络延时 - 视频上行网络抖动 - 音频下行网络延时 - 音频下行网络抖动 - 视频下行网络延时 - 视频下行网络抖动 - 上行音频丢包 - 上行视频丢包 - 下行音频丢包 - 下行视频丢包 - 下行音频无声音 - 其他 - 对端用户离线 - 对端用户无码流 - 对端用户无帧率 - 本端服务器下行无码流 - 本端服务器下行无帧率 其他情况，异常因素描述为：其他 
        :type abnormal_factor_desc: str
        :param user_count: 异常影响的用户数
        :type user_count: int
        """
        
        

        self._abnormal_type = None
        self._abnormal_type_desc = None
        self._abnormal_factor = None
        self._abnormal_factor_desc = None
        self._user_count = None
        self.discriminator = None

        self.abnormal_type = abnormal_type
        self.abnormal_type_desc = abnormal_type_desc
        self.abnormal_factor = abnormal_factor
        self.abnormal_factor_desc = abnormal_factor_desc
        self.user_count = user_count

    @property
    def abnormal_type(self):
        """Gets the abnormal_type of this AbnormalEventDimensionValue.

        异常类型： - 1：进房慢(5s加入房间失败) - 2：视频卡顿 - 3：音频卡顿 

        :return: The abnormal_type of this AbnormalEventDimensionValue.
        :rtype: int
        """
        return self._abnormal_type

    @abnormal_type.setter
    def abnormal_type(self, abnormal_type):
        """Sets the abnormal_type of this AbnormalEventDimensionValue.

        异常类型： - 1：进房慢(5s加入房间失败) - 2：视频卡顿 - 3：音频卡顿 

        :param abnormal_type: The abnormal_type of this AbnormalEventDimensionValue.
        :type abnormal_type: int
        """
        self._abnormal_type = abnormal_type

    @property
    def abnormal_type_desc(self):
        """Gets the abnormal_type_desc of this AbnormalEventDimensionValue.

        异常类型描述与异常类型对应，支持国际化，取值范围为： - 进房慢(5s加入房间失败) - 视频卡顿 - 音频卡顿 

        :return: The abnormal_type_desc of this AbnormalEventDimensionValue.
        :rtype: str
        """
        return self._abnormal_type_desc

    @abnormal_type_desc.setter
    def abnormal_type_desc(self, abnormal_type_desc):
        """Sets the abnormal_type_desc of this AbnormalEventDimensionValue.

        异常类型描述与异常类型对应，支持国际化，取值范围为： - 进房慢(5s加入房间失败) - 视频卡顿 - 音频卡顿 

        :param abnormal_type_desc: The abnormal_type_desc of this AbnormalEventDimensionValue.
        :type abnormal_type_desc: str
        """
        self._abnormal_type_desc = abnormal_type_desc

    @property
    def abnormal_factor(self):
        """Gets the abnormal_factor of this AbnormalEventDimensionValue.

        异常因素 当异常类型为1时，异常因素取值范围为： - 1：建链失败 - 2：房间非空闲 - 3：服务器异常 - 4：服务器反馈503 - 5：鉴权失败 - 6：鉴权重试 - 7：时钟同步失败 - 8：url错误 - 9：终端内部异常 - 90000004：SDK发出的加入房间信令响应超时 - 90100009：web侧没有收到MSP下发的配置信息 - 90100008：websocket链路建链失败 - 10000001：服务侧返回的异常信息 - 31000003：服务侧返回的异常信息 - 32000030：服务侧返回的异常信息 - 15：浏览器设置sdp异常 当异常类型为2或者3时，异常因素取值范围为： - 1：系统CPU占用高 - 2：App CPU占用高 - 3：音频上行网络延时 - 4：音频上行网络抖动 - 5：视频上行网络延时 - 6：视频上行网络抖动 - 7：音频下行网络延时 - 8：音频下行网络抖动 - 9：视频下行网络延时 - 10：视频下行网络抖动 - 11：上行音频丢包 - 12：上行视频丢包 - 13：下行音频丢包 - 14：下行视频丢包 - 15：下行音频无声音 - 16：其他 - 17：对端用户离线 - 18：对端用户无码流 - 19：对端用户无帧率 - 20：本端服务器下行无码流 - 21：本端服务器下行无帧率 

        :return: The abnormal_factor of this AbnormalEventDimensionValue.
        :rtype: int
        """
        return self._abnormal_factor

    @abnormal_factor.setter
    def abnormal_factor(self, abnormal_factor):
        """Sets the abnormal_factor of this AbnormalEventDimensionValue.

        异常因素 当异常类型为1时，异常因素取值范围为： - 1：建链失败 - 2：房间非空闲 - 3：服务器异常 - 4：服务器反馈503 - 5：鉴权失败 - 6：鉴权重试 - 7：时钟同步失败 - 8：url错误 - 9：终端内部异常 - 90000004：SDK发出的加入房间信令响应超时 - 90100009：web侧没有收到MSP下发的配置信息 - 90100008：websocket链路建链失败 - 10000001：服务侧返回的异常信息 - 31000003：服务侧返回的异常信息 - 32000030：服务侧返回的异常信息 - 15：浏览器设置sdp异常 当异常类型为2或者3时，异常因素取值范围为： - 1：系统CPU占用高 - 2：App CPU占用高 - 3：音频上行网络延时 - 4：音频上行网络抖动 - 5：视频上行网络延时 - 6：视频上行网络抖动 - 7：音频下行网络延时 - 8：音频下行网络抖动 - 9：视频下行网络延时 - 10：视频下行网络抖动 - 11：上行音频丢包 - 12：上行视频丢包 - 13：下行音频丢包 - 14：下行视频丢包 - 15：下行音频无声音 - 16：其他 - 17：对端用户离线 - 18：对端用户无码流 - 19：对端用户无帧率 - 20：本端服务器下行无码流 - 21：本端服务器下行无帧率 

        :param abnormal_factor: The abnormal_factor of this AbnormalEventDimensionValue.
        :type abnormal_factor: int
        """
        self._abnormal_factor = abnormal_factor

    @property
    def abnormal_factor_desc(self):
        """Gets the abnormal_factor_desc of this AbnormalEventDimensionValue.

        异常因素描述，支持国际化 当异常类型为1时，异常因素描述与异常因素对应，取值范围为： - 建链失败 - 房间非空闲 - 服务器异常 - 服务器反馈503 - 鉴权失败 - 鉴权重试 - 时钟同步失败 - url错误 - 终端内部异常 - SDK发出的加入房间信令响应超时 - web侧没有收到MSP下发的配置信息 - websocket链路建链失败 - 服务侧返回的异常信息 - 服务侧返回的异常信息 - 服务侧返回的异常信息 - 浏览器设置sdp异常 当异常类型为2或者3时，异常因素描述与异常因素对应，取值范围为： - 系统CPU占用高 - App CPU占用高 - 音频上行网络延时 - 音频上行网络抖动 - 视频上行网络延时 - 视频上行网络抖动 - 音频下行网络延时 - 音频下行网络抖动 - 视频下行网络延时 - 视频下行网络抖动 - 上行音频丢包 - 上行视频丢包 - 下行音频丢包 - 下行视频丢包 - 下行音频无声音 - 其他 - 对端用户离线 - 对端用户无码流 - 对端用户无帧率 - 本端服务器下行无码流 - 本端服务器下行无帧率 其他情况，异常因素描述为：其他 

        :return: The abnormal_factor_desc of this AbnormalEventDimensionValue.
        :rtype: str
        """
        return self._abnormal_factor_desc

    @abnormal_factor_desc.setter
    def abnormal_factor_desc(self, abnormal_factor_desc):
        """Sets the abnormal_factor_desc of this AbnormalEventDimensionValue.

        异常因素描述，支持国际化 当异常类型为1时，异常因素描述与异常因素对应，取值范围为： - 建链失败 - 房间非空闲 - 服务器异常 - 服务器反馈503 - 鉴权失败 - 鉴权重试 - 时钟同步失败 - url错误 - 终端内部异常 - SDK发出的加入房间信令响应超时 - web侧没有收到MSP下发的配置信息 - websocket链路建链失败 - 服务侧返回的异常信息 - 服务侧返回的异常信息 - 服务侧返回的异常信息 - 浏览器设置sdp异常 当异常类型为2或者3时，异常因素描述与异常因素对应，取值范围为： - 系统CPU占用高 - App CPU占用高 - 音频上行网络延时 - 音频上行网络抖动 - 视频上行网络延时 - 视频上行网络抖动 - 音频下行网络延时 - 音频下行网络抖动 - 视频下行网络延时 - 视频下行网络抖动 - 上行音频丢包 - 上行视频丢包 - 下行音频丢包 - 下行视频丢包 - 下行音频无声音 - 其他 - 对端用户离线 - 对端用户无码流 - 对端用户无帧率 - 本端服务器下行无码流 - 本端服务器下行无帧率 其他情况，异常因素描述为：其他 

        :param abnormal_factor_desc: The abnormal_factor_desc of this AbnormalEventDimensionValue.
        :type abnormal_factor_desc: str
        """
        self._abnormal_factor_desc = abnormal_factor_desc

    @property
    def user_count(self):
        """Gets the user_count of this AbnormalEventDimensionValue.

        异常影响的用户数

        :return: The user_count of this AbnormalEventDimensionValue.
        :rtype: int
        """
        return self._user_count

    @user_count.setter
    def user_count(self, user_count):
        """Sets the user_count of this AbnormalEventDimensionValue.

        异常影响的用户数

        :param user_count: The user_count of this AbnormalEventDimensionValue.
        :type user_count: int
        """
        self._user_count = user_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AbnormalEventDimensionValue):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
